@@ -24,7 +24,7 @@
  * SOFTWARE.
  */
 
-#include <linux/uaccess.h>
+#include <wrapper/uaccess.h>
 #include <wrapper/frame.h>
 #include <wrapper/types.h>
 
@@ -46,7 +46,7 @@ char get_char(struct estack_entry *reg, size_t offset)
 		char c;
 
 		/* Handle invalid access as end of string. */
-		if (unlikely(!access_ok(VERIFY_READ,
+		if (unlikely(!lttng_access_ok(VERIFY_READ,
 				reg->u.s.user_str + offset,
 				sizeof(c))))
 			return '\0';
